@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -59,6 +59,7 @@ use integer;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 use OffMirror::FileAttrRecord;
+use OffMirror::Misc;
 
 
 my $progname = 'offmirror-Packages';
@@ -89,21 +90,16 @@ foreach my $file (@package_files)
 
     if ($file ne '-')
     {
-	$file =~ s/^(.*\.(gz|z|Z|zip))$/gzip -dc < $1|/
-	    or
-	$file =~ s/^(.*\.(bz2|bz))$/bzip2 -dc < $1|/
-	    or
-	$file =~ s/^(.*)$/< $1/;
-
-	open IN, "$file"
-	    or die "Can't open file $file: $!";
+	$file = prepare_compressed_file_name_for_open( $file );
     }
     else
     {
-	open IN, "<&STDIN"
-	    or die die "Can't redirect stdin: $!";
+	$file = "<&STDIN";
     }
 
+    open IN, "$file"
+	or die "Can't open file $file: $!";
+
     while (<IN>)
     {
 	($filename)=m/^Filename:\s+(.*)/im;
