@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -64,6 +64,7 @@ sub usage
 	warn <<EOF;
 
 Usage: $progname	[-verbose] [-dry-run]		\
+			[-no-user-group]		\
 			[-force-{chown,chmod,mtime}]	\
 			[-help]
 
@@ -79,7 +80,7 @@ EOF
 
 =item -verbose
 
-Show what to do.
+Show what to do to STDERR.
 
 =item -dry-run
 
@@ -97,6 +98,10 @@ Always do chmod.
 
 Always set mtime.
 
+=item -no-user-group
+
+Do not change user/group attributes (overrides -force-chown).
+
 =item -help
 
 Display a usage summary.
@@ -112,11 +117,13 @@ L<offmirror-untar(1)>
 =cut
 
 
-my $verbose=0;
-my $dry_run=0;
-my $force_chown=0;
-my $force_chmod=0;
-my $force_mtime=0;
+my $verbose;
+my $dry_run;
+my $force_chown;
+my $force_chmod;
+my $force_mtime;
+my $no_user_group;
+
 my $help=0;
 
 GetOptions(
@@ -125,11 +132,14 @@ GetOptions(
 	'force-chown'	=> \$force_chown,
 	'force-chmod'	=> \$force_chmod,
 	'force-mtime'	=> \$force_mtime,
+	'no-user-group'	=> \$no_user_group,
 	'help'		=> \$help
 ) or usage;
 
 usage if $help;
 
+undef $force_chown if $no_user_group;
+
 shift @ARGV and usage("extra parameter specified");
 
 my $list = OffMirror::FileList::new(*STDIN);
@@ -214,7 +224,7 @@ undef @delete_dirs;
 #- delete directories
 
 
-umask 0; # to allow to create files/dirs with any permissions
+umask 0; # allow to create files/dirs with any permissions
 
 
 #+ create directories
@@ -244,7 +254,7 @@ undef @create_dirs;
 
 sub chattr($)
 {
-    my $hashref = shift;
+    my $hashref = $_[0];
 
     while ( my ($fname,$r) = each %{$hashref} )
     {
@@ -258,20 +268,23 @@ sub chattr($)
 
 	    # chown
 
-	    my $user = $r->field('user');
-	    if ( $force_chown or
-			($> == 0 and $user ne $locr->field('user')) )
+	    if ( ! $no_user_group )
 	    {
-		print STDERR "chown $user $fname\n" if $verbose;
-		my_chown($fullname, $user) unless ($dry_run);
-	    }
+		my $user = $r->field('user');
+		if ( $force_chown or
+		    ($> == 0 and $user ne $locr->field('user')) )
+		{
+		    print STDERR "chown $user $fname\n" if $verbose;
+		    my_chown($fullname, $user) unless ($dry_run);
+		}
 
-	    my $group = $r->field('group');
-	    if ( $force_chown or
-			($> == 0 and $group ne $locr->field('group')) )
-	    {
-		print STDERR "chgrp $group $fname\n" if $verbose;
-		my_chgrp($fullname, $group) unless ($dry_run);
+		my $group = $r->field('group');
+		if ( $force_chown or
+		    ($> == 0 and $group ne $locr->field('group')) )
+		{
+		    print STDERR "chgrp $group $fname\n" if $verbose;
+		    my_chgrp($fullname, $group) unless ($dry_run);
+		}
 	    }
 
 	    # chmod
@@ -308,7 +321,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
