@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -55,8 +55,9 @@ sub usage {
 	warn "\n".join(" ", @_)."\n" if @_;
 	warn <<EOF;
 
-Usage: $progname basedir \
-		[-exclude=regex] [-no-md5sums] [-pretty] [-help]
+Usage: $progname basedir [-help] [-verbose] \
+		[-exclude=regex] [-no-md5sums] [-pretty]
+		[-host=HOST] [-dir=DIR]
 
 For details, see man page.
 EOF
@@ -69,12 +70,12 @@ EOF
 
 =item basedir
 
-This required parameter specifies where the root of files tree is.
+This required parameter specifies where the root of the files tree is.
 
 =item -exclude=REGEX
 
 Perl regular expression.
-File entries matched after basedir are excluded from generated list.
+File entries matched after basedir are excluded from the generated list.
 
 The option may be repeated many times.
 
@@ -82,6 +83,9 @@ Example:
 
 -exclude='^lost\+found' -exclude='CVS'
 
+-exclude='.*' # To generate empty list
+
+
 =item -no-md5sums
 
 Don't compute MD5 digest for each of files.
@@ -90,6 +94,18 @@ Don't compute MD5 digest for each of files.
 
 Print file attribute fields aligned in columns.
 
+=item -host=HOSTNAME
+
+Override host name field in generated list header
+
+=item -dir=DIR
+
+Override dir name field in generated list header
+
+=item -verbose
+
+List to STDERR files processed
+
 =item -help
 
 Display a usage summary.
@@ -103,12 +119,16 @@ L<offmirror(1)>
 =cut
 
 
-my ( $help, $nomd5sums, $pretty, @exclude ) = (0,0,0,());
+my ( $help, $nomd5sums, $pretty, $host, $dir, $verbose, @exclude ) =
+	(undef,undef,undef,undef,undef,());
 
 GetOptions(
 	'exclude=s'	=> \@exclude,
 	'no-md5sums'	=> \$nomd5sums,
 	'pretty'	=> \$pretty,
+	'host=s'	=> \$host,
+	'dir=s'		=> \$dir,
+	'verbose'	=> \$verbose,
 	'help'		=> \$help
 ) or usage;
 
@@ -117,7 +137,8 @@ usage if $help;
 my $basedir = shift @ARGV or  usage("basedir not specified");
               shift @ARGV and usage("extra parameter specified");
 
-OffMirror::FileList::generate_list($basedir, \@exclude, !$nomd5sums, $pretty);
+OffMirror::FileList::generate_list($basedir, \@exclude, !$nomd5sums, $pretty,
+				   $host, $dir, $verbose);
 
 
 =head1 AUTHOR
@@ -126,7 +147,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
