@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -59,9 +59,9 @@ sub usage
 	warn "\n".join(" ", @_)."\n" if @_;
 	warn <<EOF;
 
-Usage: $progname src-list dst-list tar-file			\
+Usage: $progname src-list dst-list tar-file		\
 			[-tar-program=/usr/gnu/bin/tar]	\
-			[-show-cmd] [-help]
+			[-show-cmd] [-ignore-tar-errors] [-verbose] [-help]
 
 For details, see man page.
 EOF
@@ -101,6 +101,15 @@ Specifies tar program to run.
 
 Show running command line.
 
+=item -ignore-tar-errors
+
+Ignore tar errors.
+Workaround for cygwin' tar bug which always returns 1.
+
+=item -verbose
+
+List to STDERR files processed
+
 =item -help
 
 Display a usage summary.
@@ -121,11 +130,15 @@ L<offmirror-untar(1)>
 my $tar_prog='tar';
 my $tar_opts='';
 my $show_cmd;
+my $verbose;
+my $ignore_tar_errors = undef;
 my $help;
 
 GetOptions(
 	'tar-program=s'	=> \$tar_prog,
 	'show-cmd'	=> \$show_cmd,
+	'ignore-tar-errors' => \$ignore_tar_errors,
+	'verbose'	=> \$verbose,
 	'help'		=> \$help
 ) or usage;
 
@@ -154,6 +167,8 @@ else
     die "unknown tar file suffix: $tar_file";
 }
 
+$tar_opts .= '--verbose' if $verbose;
+
 
 my $basedir = OffMirror::FileList::basedir_from_file($src_list);
 
@@ -175,8 +190,10 @@ $SIG{INT} = $SIG{TERM} = $SIG{__DIE__} = \&clean;
 
 
 my $   diffcmd = "$FindBin::Bin/offmirror-diff $src_list $dst_list";
-my $    tarcmd = "(cd $basedir && $tar_prog -cf $tar_file -T- --null -b1".
-			" $tar_zopt $tar_opts)";
+my $    tarcmd = "(cd $basedir && ".
+		 "$tar_prog -cf $tar_file -b1 $tar_zopt $tar_opts".
+		 " --null -T-". # keep "--null -T-" at end of the tar cmd.
+		 ")";
 my $tarlistcmd = "$FindBin::Bin/offmirror-difflist2tar";
 
 my $cmd = "$diffcmd | $tarlistcmd | $tarcmd";
@@ -186,8 +203,15 @@ print "$cmd\n" if $show_cmd;
 if ( system("$cmd") != 0 )
 {
     my $err = $?;
-    system "rm -f $tar_file";
-    die "failed: $err";
+    unless ($ignore_tar_errors)
+    {
+	system "rm -f $tar_file";
+	die "failed: $err\n";
+    }
+    else
+    {
+	warn "failed: $err\n";
+    }
 }
 
 exit 0;
@@ -199,7 +223,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
