@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -25,7 +25,7 @@ offmirror-test - test offline files tree mirroring utility
 
 =head1 SYNOPSIS
 
-offmirror-test basedir
+offmirror-test basedir [-verbose] [-no-clean] [-no-user-group]
 
 =head1 DESCRIPTION
 
@@ -47,6 +47,7 @@ use strict;
 local $^W=1; # use warnings only since 5.006
 
 use integer;
+use Getopt::Long;
 use File::Basename;
 
 use FindBin;
@@ -62,13 +63,48 @@ sub usage
 	warn "\n".join(" ", @_)."\n" if @_;
 	warn <<EOF;
 
-Usage: [fakeroot] $progname basedir
+Usage: [fakeroot] $progname basedir [-verbose] [-no-clean] [-no-user-group]
 
 For details, see man page.
 EOF
 	exit(1);
 }
 
+=head1 OPTIONS
+
+=over 4
+
+=item basedir
+
+This required parameter specifies where the root of the files tree is.
+
+=item -verbose
+
+Show actions to STDERR.
+
+=item -no-clean
+
+Do not clean test files.
+
+=item -no-user-group
+
+Do not change user/group attributes.
+
+=back
+
+=head1 SEE ALSO
+
+L<offmirror(1)>
+
+=cut
+
+my ($verbose, $no_clean, $no_user_group);
+
+GetOptions(
+	'verbose'	=> \$verbose,
+	'no-clean'	=> \$no_clean,
+	'no-user-group'	=> \$no_user_group
+) or usage;
 
 my $basedir = shift @ARGV or  usage("no basedir specified");
               shift @ARGV and usage("extra parameter specified");
@@ -96,6 +132,7 @@ sub my_mkdir($$)
 {
     my ($dir, $mode) = @_;
 
+    printf STDERR "syscall: mkdir $dir mode=0%o\n",$mode if $verbose;
     mkdir($dir, $mode)
 	or die "can't mkdir $dir: $!";
 }
@@ -104,12 +141,17 @@ sub my_symlink($$)
 {
     my ($old, $new) = @_;
 
+    print STDERR "syscall: symlink old=$old new=$new\n" if $verbose;
     symlink($old, $new)
 	or die "can't symlink $old, $new: $!";
 }
 
 sub my_system($@)
 {
+    if ( $verbose )
+    {
+	print STDERR "system : "; print STDERR @_; print STDERR "\n";
+    }
     system(@_) == 0
 	or die "can't run command: @_: $?";
 }
@@ -117,7 +159,7 @@ sub my_system($@)
 
 sub my_clean_up()
 {
-    my_system("rm -rf @cleanlist");
+    my_system("rm -rf @cleanlist") unless $no_clean;
 }
 
 
@@ -130,10 +172,13 @@ my_clean_up();
 my_mkdir($srcdir, 0755);
 my_mkdir($dstdir, 0755);
 
-my_mkdir("$srcdir/copy-me", 0700);
-my_mkdir("$srcdir/copy-me/1", 0700);
-my_mkdir("$srcdir/copy-me/1/2", 0700);
-my_mkdir("$srcdir/copy-me/1/2/3", 0700);
+my $copyme = "copy - me";
+my $delme  = "delete - me";
+
+my_mkdir("$srcdir/$copyme", 0700);
+my_mkdir("$srcdir/$copyme/1", 0700);
+my_mkdir("$srcdir/$copyme/1/2", 0700);
+my_mkdir("$srcdir/$copyme/1/2/3", 0700);
 
 my $badname = "$srcdir/";
 for (my $i=1; $i < ord('/'); $i++)
@@ -150,22 +195,22 @@ close FH
     or die "can't close badname: $!";
 
 
-my_system("echo 6543210 >$srcdir/copy-me/file");
-my_system("echo 6543210 >$srcdir/copy-me/1/file");
-my_system("echo 6543210 >$srcdir/copy-me/1/2/file");
-my_system("echo 6543210 >$srcdir/copy-me/1/2/3/file");
+my_system("echo 6543210 >$srcdir/$copyme/file");
+my_system("echo 6543210 >$srcdir/$copyme/1/file");
+my_system("echo 6543210 >$srcdir/$copyme/1/2/file");
+my_system("echo 6543210 >$srcdir/$copyme/1/2/3/file");
 
-my_symlink("../file", "$srcdir/copy-me/1/2/3/link");
+my_symlink("../file",   "$srcdir/$copyme/1/2/3/link");
 
 
-my_mkdir("$dstdir/delete-me", 0700);
-my_mkdir("$dstdir/delete-me/1", 0700);
-my_mkdir("$dstdir/delete-me/1/2", 0700);
-my_mkdir("$dstdir/delete-me/1/2/3", 0700);
+my_mkdir("$dstdir/$delme", 0700);
+my_mkdir("$dstdir/$delme/1", 0700);
+my_mkdir("$dstdir/$delme/1/2", 0700);
+my_mkdir("$dstdir/$delme/1/2/3", 0700);
 
-my_system("echo 6543210 >$dstdir/delete-me/1/file");
-my_system("echo 6543210 >$dstdir/delete-me/1/2/file");
-my_system("echo 6543210 >$dstdir/delete-me/1/2/3/file");
+my_system("echo 6543210 >$dstdir/$delme/1/file");
+my_system("echo 6543210 >$dstdir/$delme/1/2/file");
+my_system("echo 6543210 >$dstdir/$delme/1/2/3/file");
 
 my_system("echo 12345 >$srcdir/file"); my_utime("$srcdir/file", 10000000);
 my_system("echo 12365 >$dstdir/file"); my_utime("$dstdir/file", 10000000);
@@ -176,15 +221,18 @@ $> == 0 and my_system("mknod $srcdir/chrdev c 11 11 -m 07700");
 $> == 0 and my_system("mknod $srcdir/blkdev b 11 33 -m 07700");
 
 
-my_system("$FindBin::Bin/offmirror-list $srcdir --pretty >$srclist");
-my_system("$FindBin::Bin/offmirror-list $dstdir --pretty >$dstlist");
+my_system("$FindBin::Bin/offmirror-list $srcdir -pretty >$srclist");
+my_system("$FindBin::Bin/offmirror-list $dstdir -pretty >$dstlist");
 
-my_system("$FindBin::Bin/offmirror-tar   $srclist $dstlist $tarfile");
-my_system("$FindBin::Bin/offmirror-untar $srclist $dstlist $tarfile");
+my $verbose_taropt = ''; $verbose_taropt = "-verbose -show-cmd" if $verbose;
+my_system("$FindBin::Bin/offmirror-tar   $srclist $dstlist $tarfile $verbose_taropt");
+
+my $untar_opt = ''; $untar_opt = "-no-user-group" if $no_user_group;
+my_system("$FindBin::Bin/offmirror-untar $srclist $dstlist $tarfile $untar_opt");
 
 #+ verify
-my_system("$FindBin::Bin/offmirror-list $dstdir --pretty >$dstverlist");
-my_system("$FindBin::Bin/offmirror-diff $srclist $dstverlist --pretty >$dstverdifflist");
+my_system("$FindBin::Bin/offmirror-list $dstdir -pretty >$dstverlist");
+my_system("$FindBin::Bin/offmirror-diff $srclist $dstverlist -pretty >$dstverdifflist");
 
 my $verlist = OffMirror::FileList::list_from_file($dstverdifflist);
 my $items = keys %{$verlist->{'list'}};
@@ -208,7 +256,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
