@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -62,8 +62,9 @@ sub usage
 	warn <<EOF;
 
 Usage: $progname src-list dst-list tar-file			\
-			[-tar-program=/usr/gnu/bin/tar]	\
+			[-tar-program=/usr/gnu/bin/tar]		\
 			[-tar-options='options']		\
+			[-no-user-group]			\
 			[-show-cmd] [-verbose] [-dry-run] [-help]
 
 For details, see man page.
@@ -104,13 +105,17 @@ Specifies tar program to run.
 
 Specifies additional tar program options.
 
+=item -no-user-group
+
+Do not change user/group attributes.
+
 =item -show-cmd
 
 Show running command line.
 
 =item -verbose
 
-Show what to do.
+Show what to do to STDERR.
 
 =item -dry-run
 
@@ -133,6 +138,7 @@ L<offmirror-tar(1)>
 
 my $tar_prog='tar';
 my $tar_opts='';
+my $no_user_group;
 my $show_cmd;
 my $verbose;
 my $dry_run;
@@ -144,6 +150,7 @@ my $help;
 GetOptions(
 	'tar-program=s'	=> \$tar_prog,
 	'tar-options=s'	=> \$tar_opts,
+	'no-user-group'	=> \$no_user_group,
 	'show-cmd'	=> \$show_cmd,
 	'verbose'	=> \$verbose,
 	'dry-run'	=> \$dry_run,
@@ -156,13 +163,15 @@ GetOptions(
 usage if $help;
 
 my $chattr_opts = '';
-$chattr_opts .= ' --verbose'     if $verbose;
-$chattr_opts .= ' --dry-run'     if $dry_run;
-$chattr_opts .= ' --force-chown' if $force_chown;
-$chattr_opts .= ' --force-chmod' if $force_chmod;
-$chattr_opts .= ' --force-mtime' if $force_mtime;
+$chattr_opts .= ' -verbose'       if $verbose;
+$chattr_opts .= ' -dry-run'       if $dry_run;
+$chattr_opts .= ' -force-chown'   if $force_chown;
+$chattr_opts .= ' -force-chmod'   if $force_chmod;
+$chattr_opts .= ' -force-mtime'   if $force_mtime;
+$chattr_opts .= ' -no-user-group' if $no_user_group;
 
 $tar_opts    .= ' --verbose' if $verbose;
+$tar_opts    .= ' -o'        if $no_user_group; # --no-same-owner
 
 
 my $src_list = shift @ARGV or  usage("no src-list file specified");
@@ -193,7 +202,7 @@ else
 
 my $basedir = OffMirror::FileList::basedir_from_file($dst_list);
 
-umask 0; # to allow to create files/dirs with any permissions
+umask 0; # allow to create files/dirs with any permissions
 
 
 $tar_file = abs_path(dirname($tar_file)) . '/' . basename($tar_file);
@@ -234,7 +243,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
