@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -27,7 +27,7 @@ local $^W=1; # use warnings only since 5.006
 BEGIN
 {
     use vars qw($VERSION);
-    $VERSION = do { my @r = (q$Revision: 1.17 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 1.21 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 }
 
 
@@ -35,11 +35,9 @@ BEGIN
 # $objref = OffMirror::Cache::new( func_ref )
 sub new(;&)
 {
-    my $func  = shift;
-
     my $self =
     {
-	'_func'  => $func,
+	'_func'  => $_[0],
 	'_cache' => {}
     };
 
@@ -49,7 +47,7 @@ sub new(;&)
 
 sub clear_cache($)
 {
-    shift->{'_cache'} = {};
+    $_[0]->{'_cache'} = {};
 }
 
 
