@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -30,6 +30,7 @@ use File::Stat::Bits;
 use File::Stat::ModeString;
 
 use OffMirror::User;
+use OffMirror::Misc;
 
 
 BEGIN
@@ -42,7 +43,7 @@ BEGIN
     use constant      ACTION_CHARS => 'lcda';
     use constant  COMPARISON_CHARS => scalar 'ca=';	# copy, attr copy, are equal
 
-    use constant   USERGROUP_RE => '[a-zA-Z0-9_-]+';
+    use constant   USERGROUP_RE => '[=a-zA-Z0-9_-]+';
 
     use constant        RECORD_FMT => scalar "%s %s %u %u %s %s %u %u %s %s";
     use constant PRETTY_RECORD_FMT => scalar "%s %s %3u %3u %-8s %-8s %11u %10u %32s %s";
@@ -52,7 +53,7 @@ BEGIN
 
 
     use vars qw($VERSION);
-    $VERSION = do { my @r = (q$Revision: 1.59 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 1.67 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 
     #+ use MD5 || Digest::MD5
@@ -84,8 +85,7 @@ sub field($$)
 
 my $strmodetype = sub ($)
 {
-    my $strmode = shift;
-    return substr($strmode, 0, 1);
+    return substr($_[0], 0, 1);
 };
 
 # ctor
@@ -93,9 +93,8 @@ my $strmodetype = sub ($)
 # returns objref, '?' in file type on unsupported file type
 sub stat_file($;$)
 {
-    my $name  = shift;
+    my ($name, $md5sums) = @_;
 
-    my $md5sums = shift;
     my $md5 = $md5_module->new;
     my $digest;
 
@@ -197,7 +196,7 @@ sub make_record_from($$$)
 # returns list (objref, fname) or (undef, errortext) on parse failure
 sub parse_record_line($)
 {
-    my $line = shift;
+    my $line = $_[0];
 
     my $record_re = RECORD_RE;
     die "invalid record format at line $., stopped"
@@ -213,8 +212,8 @@ sub parse_record_line($)
 	_type	=> &$strmodetype($mode),
 	_major	=> $major,
 	_minor	=> $minor,
-	_user	=> $user,
-	_group	=> $group,
+	_user	=> decode_bad_name($user),
+	_group	=> decode_bad_name($group),
 	_size   => $size,
 	_mtime  => $mtime,
 	_digest => $digest
@@ -222,7 +221,7 @@ sub parse_record_line($)
 
     bless($self, __PACKAGE__);
 
-    return ( $self, decode_file_name($name) );
+    return ( $self, decode_bad_name($name) );
 }
 
 
@@ -230,27 +229,21 @@ sub parse_record_line($)
 # returns formatted line
 sub make_record_line($$$;$)
 {
-    my $this   = shift;
+    my ($this, $fname, $action, $pretty) = @_;
 
-    my $fname  = shift;
-    $fname = encode_file_name($fname);
-
-    my $action = shift;
     $this->{_action} = $action;
 
-    my $pretty = shift;
-
     sprintf (	$pretty ? PRETTY_RECORD_FMT : RECORD_FMT,
 		$this->{_action},
 		$this->{_mode  },
 		$this->{_major },
 		$this->{_minor },
-		$this->{_user  },
-		$this->{_group },
+		encode_bad_name($this->{_user }),
+		encode_bad_name($this->{_group}),
 		$this->{_size  },
 		$this->{_mtime },
 		$this->{_digest},
-		$fname
+		encode_bad_name($fname)
 	    );
 }
 
@@ -262,9 +255,7 @@ sub make_record_line($$$;$)
 #	'a' - attributes are differ, needs to copy attributes only
 sub compare_records($$)
 {
-    my $this   = shift;
-    my $other  = shift;
-
+    my ($this, $other) = @_;
 
     if ( $this->{_type} ne $other->{_type} )
     {
@@ -287,13 +278,12 @@ sub compare_records($$)
 	if ( $this->{_digest} eq $other->{_digest} )
 	{
 	    return 'a'
-		if	($type ne 'l' and
-			       $this->{_mtime} != $other->{_mtime} ) or
-			$this->{_mode } ne $other->{_mode } or
-			$this->{_major} != $other->{_major} or
-			$this->{_minor} != $other->{_minor} or
-			$this->{_user } ne $other->{_user } or
-			$this->{_group} ne $other->{_group};
+		if ( $type ne 'l' and $this->{_mtime} != $other->{_mtime} ) or
+		   $this->{_mode } ne $other->{_mode } or
+		   $this->{_major} != $other->{_major} or
+		   $this->{_minor} != $other->{_minor} or
+		   $this->{_user } ne $other->{_user } or
+		   $this->{_group} ne $other->{_group};
 	}
 	else
 	{
@@ -317,23 +307,6 @@ sub compare_records($$)
 }
 
 
-sub encode_file_name($)
-{
-    my $res = shift;
-    $res =~ s/([\000-\037\177-\377=])/sprintf("=%02X", ord($1))/seg;
-
-    return $res;
-}
-
-sub decode_file_name($)
-{
-    my $res = shift;
-    $res =~ s/=([\da-fA-F]{2})/pack("C", hex($1))/ge;
-
-    return $res;
-}
-
-
 1;
 
 
@@ -343,7 +316,7 @@ Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 
 =head1 LICENSE
 
