@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -28,16 +28,17 @@ use Cwd 'abs_path';
 use File::Find;
 
 use OffMirror::FileAttrRecord;
+use OffMirror::Misc;
 
 
-use constant FORMAT_VERSION => scalar 1;
+use constant FORMAT_VERSION => scalar 2;
 
 # printf(fmt, hostname, basedir[, digest]);
-use constant HEADER_FMT     => scalar 'header: version='.FORMAT_VERSION.' hostdir=%s:%s';
-use constant FOOTER_FMT     => scalar 'footer: version='.FORMAT_VERSION.' hostdir=%s:%s digest=%s';
+use constant HEADER_FMT     => scalar 'header: version='.FORMAT_VERSION.' host=%s dir=%s';
+use constant FOOTER_FMT     => scalar 'footer: version='.FORMAT_VERSION.' host=%s dir=%s digest=%s';
 
 # $1: version, $2: hostname, $3: basedir, $4: digest
-use constant HDRFTR_RE      => scalar ':\s+version=(\d+)\s+hostdir=(.*):(.+)';
+use constant HDRFTR_RE      => scalar ':\s+version=(\d+)\s+host=(.*)\s+dir=(.+)';
 use constant HEADER_RE      => scalar '^header'.HDRFTR_RE.'$';
 use constant FOOTER_RE      => scalar '^footer'.HDRFTR_RE.'\s+digest=(\w+)$';
 
@@ -45,7 +46,7 @@ use constant FOOTER_RE      => scalar '^footer'.HDRFTR_RE.'\s+digest=(\w+)$';
 BEGIN
 {
     use vars qw($VERSION);
-    $VERSION = do { my @r = (q$Revision: 0.36 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 0.46 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
     #+ use MD5 || Digest::MD5
     use vars qw( $md5_module );
@@ -69,7 +70,7 @@ my $_make_header_footer = sub
 {
     my ($fmt, $hostname, $basedir, $digest) = @_;
 
-    return sprintf $fmt, $hostname, $basedir, $digest;
+    return sprintf $fmt, $hostname, encode_bad_name($basedir), $digest;
 };
 
 my $make_header = sub
@@ -89,10 +90,9 @@ my $make_footer = sub
 my $_parse_header_footer = sub
 {
     my ($re, $line) = @_;
-    my ($version, $hostname, $basedir, $digest);
 
     $line =~ m/$re/		&&
-	return ($1, $2, OffMirror::FileAttrRecord::decode_file_name($3), $4);
+	return ($1, $2, decode_bad_name($3), $4);
 
     return undef;
 };
@@ -114,7 +114,7 @@ my $parse_footer = sub
 
 my $read_line = sub
 {
-    local *FH = shift;
+    local *FH = $_[0];
 
     while (my $line = <FH>)
     {
@@ -126,20 +126,27 @@ my $read_line = sub
 };
 
 
-# generate_list( $basedir, \@exclude_list, $md5sums, $pretty )
+# generate_list( $basedir, \@exclude_list, $md5sums, $pretty,
+#                $host, $dir, $verbose )
 # generate and print list to stdout
-sub generate_list($$$$)
+sub generate_list($$$$;$$$)
 {
-    my ($basedir, $exclude_list, $md5sums, $pretty) = @_;
+    my ($basedir, $exclude_list, $md5sums, $pretty,
+	$host, $dir, $verbose) = @_;
 
     $basedir =~ s:(.*)/$:$1:;	# strip '/' from end
     $basedir = abs_path($basedir) or
 	die "can't get abs path of $basedir: $!";
 
-    my $host = `hostname` or warn "can't run hostname: $!";
-    chomp $host;
+    unless (defined $host)
+    {
+	$host = `hostname` or warn "can't run hostname: $!";
+	chomp $host;
+    }
 
-    print ( &$make_header($host, $basedir) . "\n" );
+    $dir = $basedir unless defined $dir;
+
+    print ( &$make_header($host, $dir) . "\n" );
 
     my $md5 = $md5_module->new;
 
@@ -164,11 +171,12 @@ sub generate_list($$$$)
 	my $line = $r->make_record_line($fname, 'l', $pretty);
 	$md5->add($line);
 	print ($line."\n");
+	print STDERR "$fname\n" if $verbose;
     };
 
     find($onfile, $basedir);
 
-    print ( &$make_footer($host, $basedir, $md5->hexdigest()) . "\n" );
+    print ( &$make_footer($host, $dir, $md5->hexdigest()) . "\n" );
 }
 
 
@@ -178,7 +186,7 @@ sub new($)
 {
     my $self =
     {
-	'fh'	=> shift,
+	'fh'	=> $_[0],
 	'footer'=> 0,
 	'host'	=> undef,
 	'dir'	=> undef,
@@ -194,13 +202,7 @@ sub new($)
 # $objref = OffMirror::FileList::new_from_file( $filename )
 my $new_from_file = sub ($)
 {
-    my $file = shift;
-
-    $file =~ s/^(.*\.(gz|z|Z|zip))$/gzip -dc < $1|/
-	or
-    $file =~ s/^(.*\.(bz2|bz))$/bzip2 -dc < $1|/
-	or
-    $file =~ s/^(.*)$/< $1/;
+    my $file = prepare_compressed_file_name_for_open( $_[0] );
 
     local *LIST_IN;
     open   LIST_IN, "$file"
@@ -212,7 +214,7 @@ my $new_from_file = sub ($)
 
 sub parse_first($)
 {
-    my $this = shift;
+    my $this = $_[0];
     my $line = &$read_line( $this->{'fh'} )
 	or die "can't read header at line $., stopped";
 
@@ -236,10 +238,10 @@ my $footer_re = FOOTER_RE;
 # returns ($r, $fname)
 sub parse_line($)
 {
-    my $this  = shift;
+    my $this  = $_[0];
 
     my $line = &$read_line( $this->{'fh'} );
-    unless (defined $line)
+    unless (defined $line) # EOF
     {
 	die "no footer record found, stopped"
 	    unless $this->{'footer'};
@@ -282,7 +284,7 @@ sub parse_line($)
 
 sub parse_list($)
 {
-    my $this  = shift;
+    my $this  = $_[0];
 
     $this->parse_first();
 
@@ -298,7 +300,7 @@ sub parse_list($)
 # $objref = OffMirror::FileList::list_from_file( $filename )
 sub list_from_file($)
 {
-    my $file = shift;
+    my $file = $_[0];
 
     my $this = &$new_from_file($file);
     $this->parse_list();
@@ -309,7 +311,7 @@ sub list_from_file($)
 # $basedir = basedir_from_file($file)
 sub basedir_from_file($)
 {
-    my $list = &$new_from_file(shift);
+    my $list = &$new_from_file($_[0]);
     $list->parse_first();
     my $basedir = $list->{'dir'};
     undef $list;
@@ -321,9 +323,10 @@ sub basedir_from_file($)
 # ($src_list_ref, $dst_list_ref, $pretty)
 sub diff_list($$$)
 {
-    my $srcobj = shift; my $srclist = $srcobj->{'list'};
-    my $dstobj = shift; my $dstlist = $dstobj->{'list'};
-    my $pretty = shift;
+    my ($srcobj, $dstobj, $pretty) = @_;
+
+    my $srclist = $srcobj->{'list'};
+    my $dstlist = $dstobj->{'list'};
 
     print ( &$make_header( $dstobj->{'host'}, $dstobj->{'dir'}) . "\n" );
     my $md5 = $md5_module->new;
