@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003,2004,2006 Dmitry Fedorov <dm.fedorov@gmail.com>
+# Copyright (C) 2003,2004,2006,2008 Dmitry Fedorov <dm.fedorov@gmail.com>
 #
 # This file is part of Offmirror.
 #
@@ -32,7 +32,7 @@ BEGIN
     use Exporter;
     use vars qw($VERSION @ISA @EXPORT);
 
-    $VERSION = do { my @r = (q$Revision: 1.15 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+    $VERSION = do { my @r = (q$Revision: 1.19 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
     @ISA = ('Exporter');
     @EXPORT = qw( &get_usr_name &get_usr_id &warn_no_user_once
 		  &get_grp_name &get_grp_id &warn_no_group_once );
@@ -42,7 +42,7 @@ BEGIN
 #+ get_usr_name()
 my $_get_usr_name = sub ($)
 {
-    my $uid = shift;
+    my $uid = $_[0];
     my $name = getpwuid($uid);
     $name = $uid unless defined $name;
     return $name;
@@ -54,7 +54,7 @@ my $uid_name_cache = OffMirror::Cache::new(\&$_get_usr_name);
 # on failrure returns uid number from arg
 sub get_usr_name($)
 {
-    return $uid_name_cache->get_value(shift);
+    return $uid_name_cache->get_value($_[0]);
 }
 #- get_usr_name()
 
@@ -62,7 +62,7 @@ sub get_usr_name($)
 #+ get_grp_name()
 my $_get_grp_name = sub ($)
 {
-    my $gid = shift;
+    my $gid = $_[0];
     my $name = getgrgid($gid);
     $name = $gid unless defined $name;
     return $name;
@@ -74,7 +74,7 @@ my $gid_name_cache = OffMirror::Cache::new(\&$_get_grp_name);
 # on failrure returns gid number from arg
 sub get_grp_name($)
 {
-    return $gid_name_cache->get_value(shift);
+    return $gid_name_cache->get_value($_[0]);
 }
 #- get_grp_name()
 
@@ -82,7 +82,7 @@ sub get_grp_name($)
 #+ get_usr_id()
 my $_get_usr_id = sub ($)
 {
-    my $uid = getpwnam(shift);
+    my $uid = getpwnam($_[0]);
     $uid = -1 unless defined $uid;
     return $uid;
 };
@@ -93,7 +93,7 @@ my $name_uid_cache = OffMirror::Cache::new(\&$_get_usr_id);
 # on failrure returns -1
 sub get_usr_id($)
 {
-    return $name_uid_cache->get_value(shift);
+    return $name_uid_cache->get_value($_[0]);
 }
 #- get_usr_id()
 
@@ -101,7 +101,7 @@ sub get_usr_id($)
 #+ get_grp_id()
 my $_get_grp_id = sub ($)
 {
-    my $gid = getgrnam(shift);
+    my $gid = getgrnam($_[0]);
     $gid = -1 unless defined $gid;
     return $gid;
 };
@@ -112,7 +112,7 @@ my $name_gid_cache = OffMirror::Cache::new(\&$_get_grp_id);
 # on failrure returns -1
 sub get_grp_id($)
 {
-    return $name_uid_cache->get_value(shift);
+    return $name_uid_cache->get_value($_[0]);
 }
 #- get_grp_id()
 
@@ -120,7 +120,7 @@ sub get_grp_id($)
 #+ one-time no user warning
 my $_no_user = sub ($)
 {
-    my $user = shift;
+    my $user = $_[0];
     print STDERR "No such user: $user\n";
     return 1;
 };
@@ -129,7 +129,7 @@ my $no_user = OffMirror::Cache::new(\&$_no_user);
 
 sub warn_no_user_once($)
 {
-    $no_user->get_value(shift);
+    $no_user->get_value($_[0]);
 }
 #- one-time no user warning
 
@@ -137,7 +137,7 @@ sub warn_no_user_once($)
 #+ one-time no group warning
 my $_no_group = sub ($)
 {
-    my $group = shift;
+    my $group = $_[0];
     print STDERR "No such group: $group\n";
     return 1;
 };
@@ -146,7 +146,7 @@ my $no_group = OffMirror::Cache::new(\&$_no_group);
 
 sub warn_no_group_once($)
 {
-    $no_group->get_value(shift);
+    $no_group->get_value($_[0]);
 }
 #- one-time no group warning
 
